/*! \file algebraic.cpp
 *
 * \brief Implementation of algebraic functions with different call-backs.
 */

#include <complex>

#ifndef INCLUDE_ALGEBRAIC_H_
#include "../include/algebraic.h"
#endif

#ifndef INCLUDE_LAPACK_CALLS_H_
#include "lapacke.h"
#include "../include/lapack_calls.h"
#endif

// >>> FALL-BACK FUNCTIONS DECLARATION <<< //
extern void lucin(std::complex<double> **mat, int64_t max_size, int64_t size, int &ier);
// >>>   END OF FALL-BACK FUNCTIONS    <<< //

using namespace std;

void invert_matrix(std::complex<double> **mat, lapack_int size, int &ier, lapack_int max_size) {
  ier = 0;
#ifdef USE_LAPACK
  zinvert(mat, size, ier);
#else
  lucin(mat, (int64_t)max_size, (int64_t)size, ier);
#endif
}
